==> jc-1.4.0.tar.gz: java/awt/AttributeValue.h <==
// class java.awt.AttributeValue

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AttributeValue_H_
#define _JC_java_awt_AttributeValue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AttributeValue$sub_refs	_jc_java_awt_AttributeValue$sub_refs;
typedef struct _jc_java_awt_AttributeValue$sub_nonrefs	_jc_java_awt_AttributeValue$sub_nonrefs;
typedef struct _jc_java_awt_AttributeValue$refs	_jc_java_awt_AttributeValue$refs;
typedef struct _jc_java_awt_AttributeValue$nonrefs	_jc_java_awt_AttributeValue$nonrefs;
typedef struct _jc_java_awt_AttributeValue$object	_jc_java_awt_AttributeValue$object;

typedef const struct _jc_java_awt_AttributeValue$vmethods	_jc_java_awt_AttributeValue$vmethods;
typedef const struct _jc_java_awt_AttributeValue$vtable	_jc_java_awt_AttributeValue$vtable;
typedef const struct _jc_java_awt_AttributeValue$vtype	_jc_java_awt_AttributeValue$vtype;

// Constructors
extern void _jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755(_jc_env *, struct _jc_java_awt_AttributeValue$object *, jint, struct _jc_object_array *);

// Virtual methods
extern jint _jc_java_awt_AttributeValue$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_AttributeValue$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_AttributeValue$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_AttributeValue$vmethods {
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_AttributeValue$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_AttributeValue$object *);
};

// Vtable
struct _jc_java_awt_AttributeValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
};

// Vtype
struct _jc_java_awt_AttributeValue$vtype {
	_jc_type			type;
	_jc_java_awt_AttributeValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AttributeValue$sub_refs {
	_jc_object_array	*names;
};

// Reference instance fields (object)
struct _jc_java_awt_AttributeValue$refs {
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AttributeValue$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AttributeValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
};

// Object instance structure
struct _jc_java_awt_AttributeValue$object {
	_jc_java_awt_AttributeValue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AttributeValue$vtype	*vtype;
	_jc_java_awt_AttributeValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AttributeValue$vtype _jc_java_awt_AttributeValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AttributeValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AttributeValue$class_object;

#endif	/* _JC_java_awt_AttributeValue_H_ */

==> jc-1.4.6.tar.gz: java/awt/AttributeValue.h <==
// class java.awt.AttributeValue

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AttributeValue_H_
#define _JC_java_awt_AttributeValue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AttributeValue$sub_refs	_jc_java_awt_AttributeValue$sub_refs;
typedef struct _jc_java_awt_AttributeValue$sub_nonrefs	_jc_java_awt_AttributeValue$sub_nonrefs;
typedef struct _jc_java_awt_AttributeValue$refs	_jc_java_awt_AttributeValue$refs;
typedef struct _jc_java_awt_AttributeValue$nonrefs	_jc_java_awt_AttributeValue$nonrefs;
typedef struct _jc_java_awt_AttributeValue$object	_jc_java_awt_AttributeValue$object;

typedef const struct _jc_java_awt_AttributeValue$vmethods	_jc_java_awt_AttributeValue$vmethods;
typedef const struct _jc_java_awt_AttributeValue$vtable	_jc_java_awt_AttributeValue$vtable;
typedef const struct _jc_java_awt_AttributeValue$vtype	_jc_java_awt_AttributeValue$vtype;

// Constructors
extern void _jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755(_jc_env *, struct _jc_java_awt_AttributeValue$object *, jint, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_AttributeValue$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_AttributeValue$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_AttributeValue$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_AttributeValue$vmethods {
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_AttributeValue$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_AttributeValue$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_AttributeValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
};

// Vtype
struct _jc_java_awt_AttributeValue$vtype {
	_jc_type			type;
	_jc_java_awt_AttributeValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AttributeValue$sub_refs {
	_jc_object_array	*names;
};

// Reference instance fields (object)
struct _jc_java_awt_AttributeValue$refs {
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AttributeValue$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AttributeValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
};

// Object instance structure
struct _jc_java_awt_AttributeValue$object {
	_jc_java_awt_AttributeValue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AttributeValue$vtype	*vtype;
	_jc_java_awt_AttributeValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AttributeValue$vtype _jc_java_awt_AttributeValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AttributeValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AttributeValue$class_object;

#endif	/* _JC_java_awt_AttributeValue_H_ */
